==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/0b/0b164feaceec810c0ed8a0c4691359cb.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Segment/IntegrationCampaign/IntegrationCampaignParts.php */
class __TwigTemplate_af1f61a5e550930e1d78962266282a6e extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Segment\\IntegrationCampaign;

class IntegrationCampaignParts
{
    private string \$integrationName;

    private string \$campaignId;

    /**
     * @param string \$field
     */
    public function __construct(\$field)
    {
        if (str_contains(\$field, '::')) {
            [\$integrationName, \$campaignId] = explode('::', \$field);
        } else {
            // Assuming this is a Salesforce integration for BC with pre 2.11.0
            \$integrationName = 'Salesforce';
            \$campaignId      = \$field;
        }
        \$this->integrationName = \$integrationName;
        \$this->campaignId      = \$campaignId;
    }

    public function getIntegrationName(): string
    {
        return \$this->integrationName;
    }

    public function getCampaignId(): string
    {
        return \$this->campaignId;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Segment/IntegrationCampaign/IntegrationCampaignParts.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Segment/IntegrationCampaign/IntegrationCampaignParts.php", "/var/www/mautic-ktn/app/bundles/LeadBundle/Segment/IntegrationCampaign/IntegrationCampaignParts.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/0b/0b164feaceec810c0ed8a0c4691359cb.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Segment/IntegrationCampaign/IntegrationCampaignParts.php */
class __TwigTemplate_af1f61a5e550930e1d78962266282a6e extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Segment\\IntegrationCampaign;

class IntegrationCampaignParts
{
    private string \$integrationName;

    private string \$campaignId;

    /**
     * @param string \$field
     */
    public function __construct(\$field)
    {
        if (str_contains(\$field, '::')) {
            [\$integrationName, \$campaignId] = explode('::', \$field);
        } else {
            // Assuming this is a Salesforce integration for BC with pre 2.11.0
            \$integrationName = 'Salesforce';
            \$campaignId      = \$field;
        }
        \$this->integrationName = \$integrationName;
        \$this->campaignId      = \$campaignId;
    }

    public function getIntegrationName(): string
    {
        return \$this->integrationName;
    }

    public function getCampaignId(): string
    {
        return \$this->campaignId;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Segment/IntegrationCampaign/IntegrationCampaignParts.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Segment/IntegrationCampaign/IntegrationCampaignParts.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Segment/IntegrationCampaign/IntegrationCampaignParts.php");
    }
}
